# Luxsci.Api.AuthenticationApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

| Method | HTTP request | Description |
|--------|--------------|-------------|
| [**Authentication**](AuthenticationApi.md#authentication) | **POST** /auth |  |
| [**RevokeAuthentication**](AuthenticationApi.md#revokeauthentication) | **DELETE** /auth |  |

<a name="authentication"></a>
# **Authentication**
> Authentication201Response Authentication (AuthenticationRequest? authenticationRequest = null)



In order to use any API commands, at any level, your client must first authenticate and obtain an authentication code. This authentication code can then be used to make one or more calls to API functions.    our authentication \"session\" can also be revoked, immediately invalidating all authentication codes received for it (i.e., this is a \"log out\").   In order to authenticate, you will need your API Token, API Key, and your API Host name. This API request is different from authenticated request in that you do not need to send a cookie, and the way that the request is signed is different.  See also [Authentication](/rest-api/mechanics.html#auth).

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class AuthenticationExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new AuthenticationApi(config);
            var authenticationRequest = new AuthenticationRequest?(); // AuthenticationRequest? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.Authentication(authenticationRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling AuthenticationApi.Authentication: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the AuthenticationWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.AuthenticationWithHttpInfo(authenticationRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling AuthenticationApi.AuthenticationWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **authenticationRequest** | [**AuthenticationRequest?**](AuthenticationRequest?.md) |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **201** | Standard JSON response.   No \&quot;data\&quot; keyword will be sent.   See the \&quot;auth\&quot; keyword for your new authentication token. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **Authentication**
> InlineResponse201 Authentication (string secret = null, string token = null, string user = null, string pass = null)



In order to use any API commands, at any level, your client must first authenticate and obtain an authentication code. This authentication code can then be used to make one or more calls to API functions.    our authentication "session" can also be revoked, immediately invalidating all authentication codes received for it (i.e., this is a "log out").   In order to authenticate, you will need your API Token, API Key, and your API Host name. This API request is different from authenticated request in that you do not need to send a cookie, and the way that the request is signed is different.  See also [Authentication](/rest-api/mechanics.html#auth).

### Example
```csharp
using System;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class AuthenticationExample
    {
        public void main()
        {
            var apiInstance = new AuthenticationApi();

            try
            {
                InlineResponse201 result = apiInstance.Authentication("SECRET","TOKEN");
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling AuthenticationApi.Authentication: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **secret** | **string**|  | [optional]
 **token** | **string**|  | [optional]
 **user** | **string**|  | [optional]
 **pass** | **string**|  | [optional]

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="revokeauthentication"></a>
# **RevokeAuthentication**
> RevokeAuthentication200Response RevokeAuthentication ()



Revoke your authentication session and invalidate all authorization codes received. See also [Revocation](/rest-api/mechanics.html#revoke).

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class RevokeAuthenticationExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new AuthenticationApi(config);
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string | 

            try
            {
                RevokeAuthentication200Response result = apiInstance.RevokeAuthentication();
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling AuthenticationApi.RevokeAuthentication: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the RevokeAuthenticationWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<RevokeAuthentication200Response> response = apiInstance.RevokeAuthenticationWithHttpInfo();
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling AuthenticationApi.RevokeAuthenticationWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **cookie** | **string** |  |  |

### Return type

[**RevokeAuthentication200Response**](RevokeAuthentication200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | Standard JSON response.   No \&quot;data\&quot; keyword will be sent. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

