# Luxsci.Api.SecureSendApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

| Method | HTTP request | Description |
|--------|--------------|-------------|
| [**ChangeSecureSendUserPassword**](SecureSendApi.md#changesecuresenduserpassword) | **PUT** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username}/password |  |
| [**CreateOrUpdateSecureSendUser**](SecureSendApi.md#createorupdatesecuresenduser) | **PUT** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username} |  |
| [**GetSecureSendUserList**](SecureSendApi.md#getsecuresenduserlist) | **GET** /account/{accountId}/pl/namespaces/{namespaceId}/users |  |
| [**GetSecureSendUserSingleSignOnLink**](SecureSendApi.md#getsecuresendusersinglesignonlink) | **GET** /account/{accountId}/pl/namespaces/{namespaceId}/users/{username}/password |  |

<a name="changesecuresenduserpassword"></a>
# **ChangeSecureSendUserPassword**
> Authentication201Response ChangeSecureSendUserPassword (string accountId, string namespaceId, string username, string? cookie = null, ChangeSecureSendUserPasswordRequest? changeSecureSendUserPasswordRequest = null)



You can do this with the User Update function, above. We provide a simple, direct method here as well. {{ACL: Account: SecureSend Namespaces - Manage}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class ChangeSecureSendUserPasswordExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new SecureSendApi(config);
            var accountId = "accountId_example";  // string | 
            var namespaceId = "namespaceId_example";  // string | 
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var changeSecureSendUserPasswordRequest = new ChangeSecureSendUserPasswordRequest?(); // ChangeSecureSendUserPasswordRequest? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.ChangeSecureSendUserPassword(accountId, namespaceId, username, cookie, changeSecureSendUserPasswordRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling SecureSendApi.ChangeSecureSendUserPassword: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the ChangeSecureSendUserPasswordWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.ChangeSecureSendUserPasswordWithHttpInfo(accountId, namespaceId, username, cookie, changeSecureSendUserPasswordRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling SecureSendApi.ChangeSecureSendUserPasswordWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **namespaceId** | **string** |  |  |
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |
| **changeSecureSendUserPasswordRequest** | [**ChangeSecureSendUserPasswordRequest?**](ChangeSecureSendUserPasswordRequest?.md) |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | Standard simple success |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="createorupdatesecuresenduser"></a>
# **CreateOrUpdateSecureSendUser**
> Authentication201Response CreateOrUpdateSecureSendUser (string accountId, string namespaceId, string username, string? cookie = null, CreateOrUpdateSecureSendUserRequest? createOrUpdateSecureSendUserRequest = null)



Create a new SecureSend User in a specific NameSpace. This function also validates the user’s account so the user does not have to do anything (like checking a link in his/her email) to start using the account.  If an account already exists for the specified user, then this request will merely update the user’s account, changing any data passed through. The “username” must be the email address (which is also the login) of the user to be created or updated.  When updating a user, request parameters omitted will not be updated. {{ACL: Account: SecureSend Namespaces - Manage}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class CreateOrUpdateSecureSendUserExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new SecureSendApi(config);
            var accountId = "accountId_example";  // string | 
            var namespaceId = "namespaceId_example";  // string | 
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var createOrUpdateSecureSendUserRequest = new CreateOrUpdateSecureSendUserRequest?(); // CreateOrUpdateSecureSendUserRequest? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.CreateOrUpdateSecureSendUser(accountId, namespaceId, username, cookie, createOrUpdateSecureSendUserRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling SecureSendApi.CreateOrUpdateSecureSendUser: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the CreateOrUpdateSecureSendUserWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.CreateOrUpdateSecureSendUserWithHttpInfo(accountId, namespaceId, username, cookie, createOrUpdateSecureSendUserRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling SecureSendApi.CreateOrUpdateSecureSendUserWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **namespaceId** | **string** |  |  |
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |
| **createOrUpdateSecureSendUserRequest** | [**CreateOrUpdateSecureSendUserRequest?**](CreateOrUpdateSecureSendUserRequest?.md) |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | Standard simple success |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getsecuresenduserlist"></a>
# **GetSecureSendUserList**
> GetSecureSendUserList200Response GetSecureSendUserList (string accountId, string namespaceId, string? cookie = null)



Return a list of all users in this NameSpace. {{ACL: Account: SecureSend Namespaces - Manage}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetSecureSendUserListExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new SecureSendApi(config);
            var accountId = "accountId_example";  // string | 
            var namespaceId = "namespaceId_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetSecureSendUserList200Response result = apiInstance.GetSecureSendUserList(accountId, namespaceId);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling SecureSendApi.GetSecureSendUserList: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetSecureSendUserListWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetSecureSendUserList200Response> response = apiInstance.GetSecureSendUserListWithHttpInfo(accountId, namespaceId);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling SecureSendApi.GetSecureSendUserListWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **namespaceId** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetSecureSendUserList200Response**](GetSecureSendUserList200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | This returns a list of objects. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getsecuresendusersinglesignonlink"></a>
# **GetSecureSendUserSingleSignOnLink**
> GetSecureSendUserSingleSignOnLink200Response GetSecureSendUserSingleSignOnLink (string accountId, string namespaceId, string username, string? ip = null, int? theme = null, string? cookie = null)



Create a URL that the user can click on which will automatically log the user into the SecureSend Interface without needing to enter his/her username and password. For example, if the user has already authenticated him/herself in your system, you can use this API call to get a link that can be presented to the user so the user can then access SecureSend without needing to login again (e.g. “single sign-on”).  Note 1. This API call returns a URL. You can have the user click on that URL or you can redirect him/her to it. 2. This URL is valid for 15 minutes from the time of issuance. It can be used multiple times while it is in use. 3. These URLs are invalidated if the user’s password is changed. 4. These URLs will only work for someone coming from the IP address that your specified in your request for the URL. 5. All logins via Single Sign-on are logged in the user’s History and are denoted as Single Sign-on logins therein.   {{ACL: Account: SecureSend Single Sign-On}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetSecureSendUserSingleSignOnLinkExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new SecureSendApi(config);
            var accountId = "accountId_example";  // string | 
            var namespaceId = "namespaceId_example";  // string | 
            var username = "username_example";  // string | 
            var ip = 5.33.44.1;  // string? | The public IP address that the user is currently using. The resulting URL will only work for people accessing it from this IP. (optional) 
            var theme = 1788906572;  // int? | The numerical Private Labeled Theme ID that this link should be generated for. You can find these IDs in your theme management area.<br><br>Not that the SecureSend NameSpace specified must be associated with this Theme, or the API will return an error. (optional) 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetSecureSendUserSingleSignOnLink200Response result = apiInstance.GetSecureSendUserSingleSignOnLink(accountId, namespaceId, username, ip, theme);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling SecureSendApi.GetSecureSendUserSingleSignOnLink: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetSecureSendUserSingleSignOnLinkWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetSecureSendUserSingleSignOnLink200Response> response = apiInstance.GetSecureSendUserSingleSignOnLinkWithHttpInfo(accountId, namespaceId, username, ip, theme);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling SecureSendApi.GetSecureSendUserSingleSignOnLinkWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **namespaceId** | **string** |  |  |
| **username** | **string** |  |  |
| **ip** | **string?** | The public IP address that the user is currently using. The resulting URL will only work for people accessing it from this IP. | [optional]  |
| **theme** | **int?** | The numerical Private Labeled Theme ID that this link should be generated for. You can find these IDs in your theme management area.&lt;br&gt;&lt;br&gt;Not that the SecureSend NameSpace specified must be associated with this Theme, or the API will return an error. | [optional]  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetSecureSendUserSingleSignOnLink200Response**](GetSecureSendUserSingleSignOnLink200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | Returns the URL |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

